==> mhu-lib-karaf-3.2.8-sources.jar: de/mhus/lib/karaf/DataSourceUtil.java <==
package de.mhus.lib.karaf;

import java.util.Dictionary;
import java.util.Hashtable;

import javax.sql.DataSource;

import org.osgi.framework.BundleContext;
import org.osgi.framework.InvalidSyntaxException;
import org.osgi.framework.ServiceReference;

public class DataSourceUtil {
	
	public static final String SERVICE_JNDI_NAME_KEY = "osgi.jndi.service.name";
	private BundleContext context;
	
	public DataSourceUtil(BundleContext context) {
		this.context = context;
	}

	public DataSource getDataSource(String name) {
        ServiceReference<?>[] dataSources = getDataSources();
        for (ServiceReference<?> ref : dataSources) {
            String jndiName = getServiceJndiName(ref);
            if (name.equals(jndiName)) {
                DataSource ds = (DataSource)getContext().getService(ref);
                return ds;
            }
        }
        // throw new RuntimeException("No DataSource with name " + name + " found");
        return null;
    }

	public ServiceReference<?>[] getDataSources() {
        try {
            ServiceReference<?>[] dsRefs = getContext().getServiceReferences(DataSource.class.getName(), null);
            if (dsRefs == null) {
                dsRefs = new ServiceReference[]{};
            }
            return dsRefs;
        } catch (InvalidSyntaxException e) {
            throw new RuntimeException(e);
        }
    }
	
	public String getServiceJndiName(ServiceReference<?> ref) {
        String jndiName = (String)ref.getProperty(SERVICE_JNDI_NAME_KEY);
        return jndiName;
    }
	
	public BundleContext getContext() {
		return context;
	}

	public void registerDataSource(DataSource dataSource, String name) {
        Dictionary<String, Object> properties = new Hashtable<String, Object>();
        properties.put(SERVICE_JNDI_NAME_KEY, name);
        context.registerService(DataSource.class, dataSource,properties);
	}
}

==> mhu-lib-karaf-3.3.1-sources.jar: de/mhus/lib/karaf/DataSourceUtil.java <==
package de.mhus.lib.karaf;

import java.util.Dictionary;
import java.util.Hashtable;

import javax.sql.DataSource;

import org.osgi.framework.BundleContext;
import org.osgi.framework.FrameworkUtil;
import org.osgi.framework.InvalidSyntaxException;
import org.osgi.framework.ServiceReference;
import org.osgi.service.jdbc.DataSourceFactory;

public class DataSourceUtil {
	
	public static final String SERVICE_JNDI_NAME_KEY = "osgi.jndi.service.name";
	private BundleContext context;
	
	public DataSourceUtil() {
		this.context = FrameworkUtil.getBundle(DataSourceUtil.class).getBundleContext();
	}
	
	public DataSourceUtil(BundleContext context) {
		this.context = context;
	}

	public DataSource getDataSource(String name) {
        ServiceReference<?>[] dataSources = getDataSources();
        for (ServiceReference<?> ref : dataSources) {
            String jndiName = getServiceJndiName(ref);
            if (name.equals(jndiName)) {
                DataSource ds = (DataSource)getContext().getService(ref);
                return ds;
            }
        }

        // throw new RuntimeException("No DataSource with name " + name + " found");
        return null;
    }

	@SuppressWarnings("unchecked")
	public ServiceReference<DataSource>[] getDataSources() {
        try {
            ServiceReference<?>[] dsRefs = getContext().getServiceReferences(DataSource.class.getName(), null);
            if (dsRefs == null) {
                dsRefs = new ServiceReference[]{};
            }
            return (ServiceReference<DataSource>[]) dsRefs;
        } catch (InvalidSyntaxException e) {
            throw new RuntimeException(e);
        }
    }
	
	public String getServiceJndiName(ServiceReference<?> ref) {
        String jndiName = (String)ref.getProperty(SERVICE_JNDI_NAME_KEY);
        return jndiName;
    }
	
	public BundleContext getContext() {
		return context;
	}

	public void registerDataSource(DataSource dataSource, String name) {
        Dictionary<String, Object> properties = new Hashtable<String, Object>();
        properties.put(SERVICE_JNDI_NAME_KEY, name);
        properties.put(DataSourceFactory.JDBC_DATASOURCE_NAME, name);
        
        context.registerService(DataSource.class, dataSource,properties);
	}
}
